==> Morpho-0.2.tar.gz: Morpho-0.2/src/jp/morpho/webapp/servlet/jsp/tagext/html/Events.java <==
/*
 * Copyright (c) 2003, Morpho Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the Morpho Project nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.morpho.webapp.servlet.jsp.tagext.html;

/**
 * <P>
 * Generic Attributes  events ɽޤ
 * </P>
 * <P>
 * events  HTML 4 ϼΤȤǤ
 * <PRE>
 * &lt;!ENTITY % events
 *  "onclick     %Script;       #IMPLIED  -- a pointer button was clicked --
 *   ondblclick  %Script;       #IMPLIED  -- a pointer button was double clicked--
 *   onmousedown %Script;       #IMPLIED  -- a pointer button was pressed down --
 *   onmouseup   %Script;       #IMPLIED  -- a pointer button was released --
 *   onmouseover %Script;       #IMPLIED  -- a pointer was moved onto --
 *   onmousemove %Script;       #IMPLIED  -- a pointer was moved within --
 *   onmouseout  %Script;       #IMPLIED  -- a pointer was moved away --
 *   onkeypress  %Script;       #IMPLIED  -- a key was pressed and released --
 *   onkeydown   %Script;       #IMPLIED  -- a key was pressed down --
 *   onkeyup     %Script;       #IMPLIED  -- a key was released --"
 *   &gt;
 * </PRE>
 * </P>
 * @author Kumiko Hiroi
 */
public interface Events
{
	/**
	 * <P>
	 * onclick °֤ޤ
	 * </P>
	 * @return onclick °
	 */
	public String getOnclick();

	/**
	 * <P>
	 * ondblclick °֤ޤ
	 * </P>
	 * @return ondblclick °
	 */
	public String getOndblclick();

	/**
	 * <P>
	 * onkeydown °֤ޤ
	 * </P>
	 * @return onkeydown °
	 */
	public String getOnkeydown();

	/**
	 * <P>
	 * onkeypress °֤ޤ
	 * </P>
	 * @return onkeypress °
	 */
	public String getOnkeypress();

	/**
	 * <P>
	 * onkeyup °֤ޤ
	 * </P>
	 * @return onkeyup °
	 */
	public String getOnkeyup();

	/**
	 * <P>
	 * onmousedown °֤ޤ
	 * </P>
	 * @return onmousedown °
	 */
	public String getOnmousedown();

	/**
	 * <P>
	 * onmousemove °֤ޤ
	 * </P>
	 * @return onmousemove °
	 */
	public String getOnmousemove();

	/**
	 * <P>
	 * onmouseout °֤ޤ
	 * </P>
	 * @return onmouseout °
	 */
	public String getOnmouseout();

	/**
	 * <P>
	 * onmouseover °֤ޤ
	 * </P>
	 * @return onmouseover °
	 */
	public String getOnmouseover();

	/**
	 * <P>
	 * onmouseup °֤ޤ
	 * </P>
	 * @return onmouseup °
	 */
	public String getOnmouseup();

	/**
	 * <P>
	 * onclick °ꤷޤ
	 * </P>
	 * @param onclick onclick °
	 */
	public void setOnclick(String onclick);

	/**
	 * <P>
	 * ondblclick °ꤷޤ
	 * </P>
	 * @param ondblclick ondblclick °
	 */
	public void setOndblclick(String ondblclick);

	/**
	 * <P>
	 * onkeydown °ꤷޤ
	 * </P>
	 * @param onkeydown onkeydown °
	 */
	public void setOnkeydown(String onkeydown);

	/**
	 * <P>
	 * onkeypress °ꤷޤ
	 * </P>
	 * @param onkeypress onkeypress °
	 */
	public void setOnkeypress(String onkeypress);

	/**
	 * <P>
	 * onkeyup °ꤷޤ
	 * </P>
	 * @param onkeyup onkeyup °
	 */
	public void setOnkeyup(String onkeyup);

	/**
	 * <P>
	 * onmousedown °ꤷޤ
	 * </P>
	 * @param onmousedown onmousedown °
	 */
	public void setOnmousedown(String onmousedown);

	/**
	 * <P>
	 * onmousemove °ꤷޤ
	 * </P>
	 * @param onmousemove onmousemove °
	 */
	public void setOnmousemove(String onmousemove);

	/**
	 * <P>
	 * onmouseout °ꤷޤ
	 * </P>
	 * @param onmouseout onmouseout °
	 */
	public void setOnmouseout(String onmouseout);

	/**
	 * <P>
	 * onmouseover °ꤷޤ
	 * </P>
	 * @param onmouseover onmouseover °
	 */
	public void setOnmouseover(String onmouseover);

	/**
	 * <P>
	 * onmouseup °ꤷޤ
	 * </P>
	 * @param onmouseup onmouseup °
	 */
	public void setOnmouseup(String onmouseup);
}

==> Morpho-1.0.1.tar.gz: Morpho-1.0.1/src/jp/morpho/webapp/servlet/jsp/tagext/html/Events.java <==
/*
 * Copyright (c) 2003, Morpho Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the Morpho Project nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.morpho.webapp.servlet.jsp.tagext.html;

/**
 * <P>
 * Generic Attributes  events \܂B
 * </P>
 * <P>
 * events  HTML 4 `͎̂ƂłB
 * <PRE>
 * &lt;!ENTITY % events
 *  "onclick     %Script;       #IMPLIED  -- a pointer button was clicked --
 *   ondblclick  %Script;       #IMPLIED  -- a pointer button was double clicked--
 *   onmousedown %Script;       #IMPLIED  -- a pointer button was pressed down --
 *   onmouseup   %Script;       #IMPLIED  -- a pointer button was released --
 *   onmouseover %Script;       #IMPLIED  -- a pointer was moved onto --
 *   onmousemove %Script;       #IMPLIED  -- a pointer was moved within --
 *   onmouseout  %Script;       #IMPLIED  -- a pointer was moved away --
 *   onkeypress  %Script;       #IMPLIED  -- a key was pressed and released --
 *   onkeydown   %Script;       #IMPLIED  -- a key was pressed down --
 *   onkeyup     %Script;       #IMPLIED  -- a key was released --"
 *   &gt;
 * </PRE>
 * </P>
 * @author Kumiko Hiroi
 */
public interface Events
{
	/**
	 * <P>
	 * onclick Ԃ܂B
	 * </P>
	 * @return onclick 
	 */
	public String getOnclick();

	/**
	 * <P>
	 * ondblclick Ԃ܂B
	 * </P>
	 * @return ondblclick 
	 */
	public String getOndblclick();

	/**
	 * <P>
	 * onkeydown Ԃ܂B
	 * </P>
	 * @return onkeydown 
	 */
	public String getOnkeydown();

	/**
	 * <P>
	 * onkeypress Ԃ܂B
	 * </P>
	 * @return onkeypress 
	 */
	public String getOnkeypress();

	/**
	 * <P>
	 * onkeyup Ԃ܂B
	 * </P>
	 * @return onkeyup 
	 */
	public String getOnkeyup();

	/**
	 * <P>
	 * onmousedown Ԃ܂B
	 * </P>
	 * @return onmousedown 
	 */
	public String getOnmousedown();

	/**
	 * <P>
	 * onmousemove Ԃ܂B
	 * </P>
	 * @return onmousemove 
	 */
	public String getOnmousemove();

	/**
	 * <P>
	 * onmouseout Ԃ܂B
	 * </P>
	 * @return onmouseout 
	 */
	public String getOnmouseout();

	/**
	 * <P>
	 * onmouseover Ԃ܂B
	 * </P>
	 * @return onmouseover 
	 */
	public String getOnmouseover();

	/**
	 * <P>
	 * onmouseup Ԃ܂B
	 * </P>
	 * @return onmouseup 
	 */
	public String getOnmouseup();

	/**
	 * <P>
	 * onclick ݒ肵܂B
	 * </P>
	 * @param onclick onclick 
	 */
	public void setOnclick(String onclick);

	/**
	 * <P>
	 * ondblclick ݒ肵܂B
	 * </P>
	 * @param ondblclick ondblclick 
	 */
	public void setOndblclick(String ondblclick);

	/**
	 * <P>
	 * onkeydown ݒ肵܂B
	 * </P>
	 * @param onkeydown onkeydown 
	 */
	public void setOnkeydown(String onkeydown);

	/**
	 * <P>
	 * onkeypress ݒ肵܂B
	 * </P>
	 * @param onkeypress onkeypress 
	 */
	public void setOnkeypress(String onkeypress);

	/**
	 * <P>
	 * onkeyup ݒ肵܂B
	 * </P>
	 * @param onkeyup onkeyup 
	 */
	public void setOnkeyup(String onkeyup);

	/**
	 * <P>
	 * onmousedown ݒ肵܂B
	 * </P>
	 * @param onmousedown onmousedown 
	 */
	public void setOnmousedown(String onmousedown);

	/**
	 * <P>
	 * onmousemove ݒ肵܂B
	 * </P>
	 * @param onmousemove onmousemove 
	 */
	public void setOnmousemove(String onmousemove);

	/**
	 * <P>
	 * onmouseout ݒ肵܂B
	 * </P>
	 * @param onmouseout onmouseout 
	 */
	public void setOnmouseout(String onmouseout);

	/**
	 * <P>
	 * onmouseover ݒ肵܂B
	 * </P>
	 * @param onmouseover onmouseover 
	 */
	public void setOnmouseover(String onmouseover);

	/**
	 * <P>
	 * onmouseup ݒ肵܂B
	 * </P>
	 * @param onmouseup onmouseup 
	 */
	public void setOnmouseup(String onmouseup);
}
